new_async_https_connector

Function new_async_https_connector 

pub fn new_async_https_connector() -> Result<HttpsConnector<HttpConnector<AsyncHyperResolver>>, Error>
Available on crate feature hyper-tls-connector only.
A helper function to create an https connector from hyper-tls and a dns task with the default configuration.